"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const launchers_1 = require("./launchers");
const utils_1 = require("./utils");
function launchTerminal(execFilePath, options) {
    const { split, terminalApp } = options;
    const platform = process.platform;
    const isWindows = /^win/.test(platform);
    const isMac = /darwin/.test(platform);
    const isLinux = /linux/.test(platform);
    const isIterm = terminalApp === "iTerm.app";
    const isTmux = !!process.env.TMUX_PANE;
    let launcher;
    if (split) {
        if (isTmux) {
            launcher = launchers_1.tmux;
        }
        else if (isIterm) {
            launcher = launchers_1.iterm;
        }
    }
    else if (isMac) {
        launcher = launchers_1.mac;
    }
    else if (isWindows) {
        launcher = launchers_1.windows;
    }
    else if (isLinux) {
        launcher = launchers_1.linux;
    }
    if (!launcher) {
        throw new utils_1.ErrorMessage(`Could not recognize the OS ${platform}`);
    }
    launcher(execFilePath, options);
}
exports.default = launchTerminal;
//# sourceMappingURL=launchTerminal.js.map